@@ -38,13 +38,17 @@ ivmodel <- function(Y,D,Z,X,intercept=TRUE,
   if(length(Y) != length(D)) stop("Dimension of Y and D are not the same!")
 
   # Error checking: check Z and convert "strings" into factors
-  Z = data.frame(Z); stringIndex = sapply(Z,is.character); Z[stringIndex] = lapply(Z[stringIndex],as.factor)
+  #                 convert logical Z to numeric Z
+  Z = data.frame(Z); stringIndex = sapply(Z,is.character); Z[,stringIndex] = lapply(Z[,stringIndex],as.factor)
+  logicalIndex = sapply(Z,is.logical); Z[,logicalIndex] = Z[,logicalIndex] + 0;
   if(nrow(Z) != length(Y)) stop("Row dimension of Z and Y are not equal!")
   colnames(Z) = paste("Z",colnames(Z),sep="")
 
   # Error checking: check X and convert "strings" into factors
+  #                 convert logical X to numeric X
   if(!missing(X)) {
-    X = data.frame(X); stringIndex = sapply(X,is.character); X[stringIndex] = lapply(X[stringIndex],as.factor)
+    X = data.frame(X); stringIndex = sapply(X,is.character); X[,stringIndex] = lapply(X[,stringIndex],as.factor)
+    logicalIndex = sapply(X,is.logical); X[,logicalIndex] = X[,logicalIndex] + 0
 	  if(nrow(X) != length(Y)) stop("Row dimension of X and Y are not equal!")
 	  colnames(X) = paste("X",colnames(X),sep="")
   }
